# exam-terminal

Hey Kris, buddy, you ok?...That's good.... if you want to test it really quick:

- `exam-terminal --help`
- `exam-terminal exams/sample_exam.yml`

If you want to do the cool kids `pipenv` thingy that I just learned and is common knowledge for everyone else except me:

- Go to this directory
- `pipenv install`
- `pipenv shell`
